# -*- coding: utf-8 -*-
from annoying.fields import AutoOneToOneField
from django.db import models
from byro.common.models.choices import Choices

class MembershipTypes(Choices):
    FULL = "Vollmitglied"
    SUPP = "Fördermitglied"

class SchaffenProfile(models.Model):
    member = AutoOneToOneField(
        to='members.Member',
        on_delete=models.CASCADE,
        related_name='profile_schaffen',
    )
    membership_type = models.CharField(
        max_length=MembershipTypes.max_length,
        verbose_name=("Art der Mitgliedschaft"),
        choices=MembershipTypes.choices,
        default=MembershipTypes.FULL,
    )
    is_keyholder = models.BooleanField(
        default=False,
        verbose_name=("Ist schließberechtigt"),
    )
    has_physical_key = models.BooleanField(
        default=False,
        verbose_name=("Besitzt physischen Schlüssel"),
    )
    is_in_info_channels = models.BooleanField(
        default=False,
        verbose_name=("Ist aufgenommen in Infokanäle"),
    )
    messenger = models.CharField(
        max_length=100,
        verbose_name=("Messenger (Telegram)"),
        null=True,
        blank=True
    )
    wiki = models.CharField(
        max_length=100,
        verbose_name=("Wiki-Benutzername"),
        null=True,
        blank=True
    )
    schaffen_email = models.EmailField(
        max_length=100,
        verbose_name=("Schaffenburg E-Mail-Adresse"),
        null=True,
        blank=True
    )
    function = models.CharField(
        max_length=200,
        verbose_name=("Vereinsfunktion"),
        null=True,
        blank=True
    )
